@@ -8,8 +8,12 @@ class MYSQL:
     pool_connections = {}
 
     @classmethod
-    def initialize_connections(cls):
-        connections = get_data_yaml_dict(cls.__name__.lower())
+    def initialize_connections(cls, environment=None):
+        if environment is None:
+            connections = get_data_yaml_dict(cls.__name__.lower())
+        else:
+            connections = get_data_yaml_dict(cls.__name__.lower(), environment)
+
         for connection in connections.keys():
             c = connections[connection]
             db_url = {
